import { useMemo } from 'react';
import useCurrentApp from './useCurrentApp';
import { of } from 'rxjs';
import { useObservableState } from '@equinor/fusion-observable/react';
/**
 * Observers the stream of current app initialized modules
 *
 * __Warning:__ type hint templates are only hints, this does not check if the modules are actually enabled!
 *
 * @template TModule type hint modules which the application has configured
 * @returns the observable instance of initialized modules of the application
 */
export const useCurrentAppModules = () => {
    var _a;
    const { currentApp, error: appError } = useCurrentApp();
    const modules$ = useMemo(() => currentApp
        ? currentApp.instance$
        : of(null), [currentApp]);
    const { value: modules, error, complete, } = useObservableState(modules$, {
        initial: currentApp === undefined ? undefined : ((_a = currentApp === null || currentApp === void 0 ? void 0 : currentApp.instance) !== null && _a !== void 0 ? _a : null),
    });
    return {
        modules,
        error: error !== null && error !== void 0 ? error : appError,
        complete,
    };
};
export default useCurrentAppModules;
//# sourceMappingURL=useCurrentAppModules.js.map